# External buildroot tree for stm32f769 discovery board #

This repository provides an external buildroot tree to be used with at least buildroot 2021.02 for the stm32f769 discovery board from STMicroelectronics.

It builds a minimal operating system for the target:
* Das U-Boot bootloader.
* Minimal Linux kernel.
* Very small userspace (minimal busybox).

The current configuration is built using a prebuilt toolchain from [Bootlin](https://bootlin.com/) to accelerate the build.

## How to build ##

First install Buildroot's required dependencies. See:
[The buildroot user manual, chapter 2: System requirements](https://buildroot.org/downloads/manual/manual.html#requirement)

Then set up the required source code:

```
mkdir STM32F769DISCO && cd STM32F769DISCO
wget 'https://buildroot.org/downloads/buildroot-2021.02.7.tar.gz'
tar -xf buildroot-2021.02.7.tar.gz
mv buildroot-2021.02.7 buildroot
git clone 'https://git.lumina-sensum.com/git/LuminaSensum/buildroot-stm32f769-disco.git'
export BR2_EXTERNAL="$PWD/buildroot-stm32f769-disco"
```

Build the image:

```
cd buildroot
make O=output_build stm32f769-disco_defconfig
cd output_build
make
cd ../..
```

## Flashing ##

To flash the bootloader, run the provided flash.sh script which is located in the external tree:

```
buildroot-stm32f769-disco/board/stm32f769-disco/flash.sh buildroot/output_build
```

## Installing the operating system ##

During build, buildroot creates the sdcard.img file inside the images directory, which you can then simply burn onto a micro sd card using dd:

```
sudo dd if=buildroot-stm32f769-disco/output_build/images/sdcard.img of=/dev/sdX
 ```

* Notes:
	* This will destroy any data stored on the micro sd card!
	* Replace sdX with the correct device node name for your micro sd card!
